@@ -302,7 +302,7 @@ def _infdiag_todot(diag):
   ''' .format(gum.config["influenceDiagram", "default_chance_bgcolor"],
               gum.config["influenceDiagram", "default_chance_fgcolor"],
               gum.config["influenceDiagram", "default_chance_shape"])
-  for node in diag.ids():
+  for node in diag.nodes():
     if diag.isChanceNode(node):
       res += '   "'+diag.variable(node).name()+'";'+"\n"
 
@@ -314,7 +314,7 @@ def _infdiag_todot(diag):
   ''' .format(gum.config["influenceDiagram", "default_decision_bgcolor"],
               gum.config["influenceDiagram", "default_decision_fgcolor"],
               gum.config["influenceDiagram", "default_decision_shape"])
-  for node in diag.ids():
+  for node in diag.nodes():
     if diag.isDecisionNode(node):
       res += '   "'+diag.variable(node).name()+'";'+"\n"
 
@@ -326,15 +326,15 @@ def _infdiag_todot(diag):
   ''' .format(gum.config["influenceDiagram", "default_utility_bgcolor"],
               gum.config["influenceDiagram", "default_utility_fgcolor"],
               gum.config["influenceDiagram", "default_utility_shape"])
-  for node in diag.ids():
+  for node in diag.nodes():
     if diag.isUtilityNode(node):
       res += '   "'+diag.variable(node).name()+'";'+"\n"
 
   # arcs
   res += "\n"
-  for node in diag.ids():
+  for node in diag.nodes():
     for chi in diag.children(node):
-      res += '  "'+diag.variable(node).name()+'"->"'+diag.variable(chi).name()+';'+"\n"
+      res += '  "'+diag.variable(node).name()+'"->"'+diag.variable(chi).name()+'";'+"\n"
   res += "}"
   return res
 
@@ -679,7 +679,7 @@ def getInference(bn, engine=None, evs=None, targets=None, size=None,  nodeColor=
   return getGraph(BNinference2dot(bn, size, engine, evs, targets,  nodeColor, arcWidth, arcColor, cmap, cmapArc), size)
 
 
-def _reprPotential(pot, digits=4, withColors=True, varnames=None, asString=False):
+def _reprPotential(pot, digits=None, withColors=True, varnames=None, asString=False):
   """
   return a representation of a gum.Potential as a HTML table.
   The first dimension is special (horizontal) due to the representation of conditional probability table
@@ -704,10 +704,15 @@ def _reprPotential(pot, digits=4, withColors=True, varnames=None, asString=False
       g = int(127 + val * 128)
       b = 100
       s += "color:black;background-color:" + _rgb(r, g, b) + ";"
-    s += "text-align:right;'>{:." + \
-        gum.config['notebook', 'potential_visible_digits'] + "f}</td>"
+    s += "text-align:right;'>{:." + str(digits) + "f}</td>"
     return s.format(val)
 
+  if digits is None:
+    digits=gum.config['notebook', 'potential_visible_digits']
+
+  if gum.config["notebook", "potential_with_colors"] == "False":
+    withColors = False
+
   html = list()
   html.append('<table style="border:1px solid black;">')
   if pot.empty():
@@ -820,7 +825,7 @@ def __isKindOfProba(pot):
   return True
 
 
-def showPotential(pot, digits=4, withColors=None, varnames=None):
+def showPotential(pot, digits=None, withColors=None, varnames=None):
   """
   show a gum.Potential as a HTML table.
   The first dimension is special (horizontal) due to the representation of conditional probability table
@@ -832,13 +837,16 @@ def showPotential(pot, digits=4, withColors=None, varnames=None):
   :return: the display of the potential
   """
   if withColors is None:
-    withColors = __isKindOfProba
+    if gum.config["notebook", "potential_with_colors"] == "False":
+      withColors = False
+    else:
+      withColors = __isKindOfProba(pot)
 
   display(_reprPotential(
       pot, digits, withColors, varnames, asString=False))
 
 
-def getPotential(pot, digits=4, withColors=None, varnames=None):
+def getPotential(pot, digits=None, withColors=None, varnames=None):
   """
   return a HTML string of a gum.Potential as a HTML table.
   The first dimension is special (horizontal) due to the representation of conditional probability table
@@ -850,7 +858,10 @@ def getPotential(pot, digits=4, withColors=None, varnames=None):
   :return: the HTML string
   """
   if withColors is None:
-    withColors = __isKindOfProba(pot)
+    if gum.config["notebook", "potential_with_colors"] == "False":
+      withColors = False
+    else:
+      withColors = __isKindOfProba(pot)
 
   return _reprPotential(pot, digits, withColors, varnames, asString=True)
 
@@ -958,6 +969,8 @@ def getInferenceEngine(ie, inferenceCaption):
 
 # adding _repr_html_ to some pyAgrum classes !
 gum.BayesNet._repr_html_ = lambda self: getBN(self)
+gum.BayesNetFragment._repr_html_ = lambda self: getBN(self)
+
 gum.Potential._repr_html_ = lambda self: getPotential(self)
 gum.LazyPropagation._repr_html_ = lambda self: getInferenceEngine(
     self, "Lazy Propagation on this BN")
@@ -969,7 +982,7 @@ gum.DAG._repr_html_ = lambda self: getDot(self.toDot())
 gum.CliqueGraph._repr_html_ = lambda self: getDot(self.toDot())
 gum.EssentialGraph._repr_html_ = lambda self: getDot(self.toDot())
 gum.MarkovBlanket._repr_html_ = lambda self: getDot(self.toDot())
-
+gum.InfluenceDiagram._repr_html_ = lambda self: getDot(_infdiag_todot(self))
 
 mpl.rcParams['figure.facecolor'] = gum.config["notebook", "figure_facecolor"]
 IPython.display.set_matplotlib_formats(gum.config["notebook", "graph_format"])
